@@ -54,11 +54,11 @@ App::CELL - Configuration, Error-handling, Localization, and Logging
 
 =head1 VERSION
 
-Version 0.226
+Version 0.227
 
 =cut
 
-our $VERSION = '0.226';
+our $VERSION = '0.227';
 
 
 
@@ -219,7 +219,7 @@ directory (available only after sitedir has been successfully loaded)
 =cut
 
 sub sitedir { 
-    return '' if not $App::CELL::Load::sitedir_loaded;
+    return '' if not $App::CELL::Load::sitedir;
     return $App::CELL::Load::sitedir;
 }
 
