@@ -46,11 +46,11 @@ App::CELL::Guide - Introduction to App::CELL (POD-only module)
 
 =head1 VERSION
 
-Version 0.226
+Version 0.227
 
 =cut
 
-our $VERSION = '0.226';
+our $VERSION = '0.227';
 
 
 
@@ -215,8 +215,11 @@ log messages:
 
 To actually see your log messages, you have to do something like this:
 
-    use Log::Any::Adapter ('File', $ENV{'HOME'} . '/tmp/CELLtest.log');
+    use Log::Any::Adapter ( 'File', $ENV{'HOME'} . '/CELLtest.log' );
 
+or, even simpler:
+
+    use Log::Any::Adapter ( 'Stderr' );
 
 
 
